previewContent abstract method

Future<void> previewContent(
  1. String contentId
)

This is an experimental feature and it can have breaking changes Previews the content associated with the given contentId. This method fetches and displays the content for preview purposes.

Implementation

Future<void> previewContent(String contentId);