previewContent abstract method
This is an experimental feature and it can have breaking changes
Previews the content associated with the given contentId.
This method fetches and displays the content for preview purposes.
Implementation
Future<void> previewContent(String contentId);